@@ -1,4 +1,3 @@
-import string
 from datetime import datetime
 
 from django.conf import settings
@@ -32,10 +31,8 @@ class PluginTypeManager(models.Manager):
         the plugin_type if necessary. Lookups are cached so that subsequent
         lookups for the same plugin_type don't hit the database.
         """
-        plugin_type_cache_name = plugin_type.translate(
-            string.maketrans("", ""), string.whitespace)
+        plugin_type_cache_name = "".join(plugin_type.split())
         key = "PluginTypeManager:get_by_plugin_type:%s" % plugin_type_cache_name
-
         a = cache.get(key)
         if a is None or force:
             a, created = self.get_or_create(name=plugin_type)
