@@ -1,4 +1,4 @@
-from django.utils.translation import ugettext as _
+
 
 # following example from django/contrib/auth/management/__init__.py
 def _get_permission_codename(plugin, action):
@@ -9,6 +9,7 @@ def _get_permission_codename(plugin, action):
         name = plugin.__name__
     return u'%s_%s_plugin' % (action, name.lower())
 
+
 def _get_all_permissions(plugin):
     "Returns (codename, name) for all permissions in this plugin."
     perms = []
@@ -17,6 +18,7 @@ def _get_all_permissions(plugin):
                       u'Can %s %s plugin' % (action, plugin.verbose_name)))
     return perms + list(plugin.permissions)
 
+
 def create_permissions(plugin):
     from django.contrib.contenttypes.models import ContentType
     from django.contrib.auth.models import Permission
@@ -69,6 +71,7 @@ class BasePlugin(object):
         """
         This should return the content when plugin is shown.
         """
+        from django.utils.translation import ugettext as _
         raise NotImplemented(_(u"render needs to be implemented"))
 
     @property
@@ -173,6 +176,9 @@ class BaseModelPlugin(BasePlugin):
         """ Generic plugin rendering
 
         """
+        from django.template.loader import render_to_string
+        from django.template import RequestContext
+
         obj = self.get_obj()
         if not obj:
             return "%s no longer exists." % (self.verbose_name)
